@@ -27,7 +27,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Henryhaoson"
     author_url = "https://git.17bdc.com/android-apps/sentry-dingtalk"
-    version = "2.0.6"
+    version = "2.0.7"
     resource_links = [
         ("Report Issue", "https://git.17bdc.com/android-apps/sentry-dingtalk/issues"),
         ("View Source", "https://git.17bdc.com/android-apps/sentry-dingtalk"),
@@ -120,6 +120,20 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
             "charset": "utf8"
         }
 
+        data_optional = {
+            "msgtype": "markdown",
+            "markdown": {
+                "title": group.title,
+                "text": payload,
+            },
+        }
+        # 可选 webhook，不会 @ 成员
+        if len(webhook_optional) != 0:
+            requests.post(webhook_optional, data=json.dumps(
+                data_optional), headers=headers)
+
+        # 必填 webhook，如果配置了 @ 成员，会执行
+        payload = f"{payload} {ats_ding_str} \n\n"
         data = {
             "msgtype": "markdown",
             "markdown": {
@@ -131,11 +145,4 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
                 "isAtAll": "false"
             }
         }
-        # 可选 webhook，不会 @ 成员
-        if len(webhook_optional) != 0:
-            requests.post(webhook_optional, data=json.dumps(
-                data), headers=headers)
-
-        # 必填 webhook，如果配置了 @ 成员，会执行
-        payload = f"{payload} {ats_ding_str} \n\n"
         requests.post(webhook, data=json.dumps(data), headers=headers)
